==> react-native-hotqa-sdk-0.1.1.tgz: package/src/components/image-choice/index.js <==
/* eslint-disable react-hooks/exhaustive-deps */
import React, {useRef, useEffect, useMemo} from 'react';
import {
  StyleSheet,
  TouchableOpacity,
  Image,
  Dimensions,
  FlatList,
  View,
} from 'react-native';
import {onConfigurations} from '../../common/helper';
import AntDesign from 'react-native-vector-icons/AntDesign';
import SharePreference from '../../common/SharePreference';
import Video from 'react-native-video';
import Sound from 'react-native-sound';
import ic_play from '../../assets/images/ic_play.png';
import {color_blue, color_orange} from '../../assets/colors';
AntDesign.loadFont();

export default (props) => {
  const {
    type,
    data,
    item_question,
    dispatch,
    user_answer,
    isFinish,
    audio,
  } = props;

  // let sound = null;

  // console.log('choose imgae', keyPage, index);

  data.map((item) => {
    user_answer.forEach((answer) => {
      if (answer.question_id === item_question.id) {
        if (item.value === answer.user_answer.value) {
          item.selected = true;
        } else {
          item.selected = false;
        }
      }
    });
    return item;
  });

  // if (keyPage === index) {
  //   sound = new Sound(
  //     JSON.parse(item_question.extra)[0].value,
  //     null,
  //     (error) => {
  //       audio(sound);
  //       sound.play();
  //     },
  //   );
  // }

  const renderItem = ({item, index}) => {
    const items = item;
    return (
      <View style={styles.container}>
        <TouchableOpacity
          disabled={isFinish}
          onPress={() => {
            audio();
            onConfigurations({...item_question, items}, user_answer, dispatch);
          }}
          style={[styles.configView, item.selected && styles.imgSelected]}>
          <Image
            style={styles.image}
            source={{uri: item.data.value}}
            resizeMode="contain"
          />
        </TouchableOpacity>
        {item.correct === 1 && isFinish && (
          <AntDesign
            name="checkcircle"
            style={{fontSize: 30, color: 'green'}}
          />
        )}
        {item.correct === 0 && isFinish && (
          <AntDesign name="closecircleo" style={{fontSize: 30, color: 'red'}} />
        )}
      </View>
    );
  };

  return (
    <View>
      <FlatList
        data={data}
        numColumns={2}
        renderItem={renderItem}
        keyExtractor={(item, index) => index.toString()}
      />
    </View>
  );
};

const width = Dimensions.get('screen').width / 3.5;
const widthImage = Dimensions.get('screen').width / 4.8;

const styles = StyleSheet.create({
  container: {
    width: width,
    flexDirection: 'row',
    alignItems: 'center',
    marginVertical: 10,
  },
  configView: {
    width: widthImage,
    borderRadius: 20,
    marginVertical: '2%',
    alignItems: 'center',
    marginHorizontal: 20,
  },
  imgSelected: {
    borderColor: color_orange,
    borderWidth: 2,
    borderRadius: 20,
  },
  image: {
    width: widthImage,
    height: widthImage,
  },
});

==> react-native-hotqa-sdk-0.1.5.tgz: package/src/components/image-choice/index.js <==
/* eslint-disable react-hooks/exhaustive-deps */
import React, {useRef, useEffect, useMemo} from 'react';
import {
  StyleSheet,
  TouchableOpacity,
  Image,
  Dimensions,
  FlatList,
  View,
} from 'react-native';
import {onConfigurations} from '../../common/helper';
import AntDesign from 'react-native-vector-icons/AntDesign';
import SharePreference from '../../common/SharePreference';
import Video from 'react-native-video';
import Sound from 'react-native-sound';
import ic_play from '../../assets/images/ic_play.png';
import {color_blue, color_orange} from '../../assets/colors';
AntDesign.loadFont();

export default (props) => {
  const {
    type,
    data,
    item_question,
    dispatch,
    user_answer,
    isFinish,
    audio,
  } = props;

  // let sound = null;

  // console.log('choose imgae', keyPage, index);

  data.map((item) => {
    user_answer.forEach((answer) => {
      if (answer.question_id === item_question.id) {
        if (item.value === answer.user_answer.value) {
          item.selected = true;
        } else {
          item.selected = false;
        }
      }
    });
    return item;
  });

  // if (keyPage === index) {
  //   sound = new Sound(
  //     JSON.parse(item_question.extra)[0].value,
  //     null,
  //     (error) => {
  //       audio(sound);
  //       sound.play();
  //     },
  //   );
  // }

  const renderItem = ({item, index}) => {
    const items = item;
    return (
      <View style={styles.container}>
        <TouchableOpacity
          disabled={isFinish}
          onPress={() => {
            audio();
            onConfigurations({...item_question, items}, user_answer, dispatch);
          }}
          style={[styles.configView]}>
          <Image
            style={[styles.image, item.selected && styles.imgSelected]}
            source={{uri: item.data.value}}
            resizeMode="contain"
          />
        </TouchableOpacity>
        {item.correct === 1 && isFinish && (
          <AntDesign
            name="checkcircle"
            style={{fontSize: 30, color: 'green'}}
          />
        )}
        {item.correct === 0 && isFinish && (
          <AntDesign name="closecircleo" style={{fontSize: 30, color: 'red'}} />
        )}
      </View>
    );
  };

  return (
    <View>
      <FlatList
        data={data}
        numColumns={2}
        renderItem={renderItem}
        keyExtractor={(item, index) => index.toString()}
      />
    </View>
  );
};

const width = Dimensions.get('screen').width / 3.5;
const widthImage = Dimensions.get('screen').width / 4.8;

const styles = StyleSheet.create({
  container: {
    width: width,
    flexDirection: 'row',
    alignItems: 'center',
    marginVertical: 10,
  },
  configView: {
    width: widthImage,
    borderRadius: 20,
    marginVertical: '2%',
    alignItems: 'center',
    marginHorizontal: 20,
  },
  imgSelected: {
    borderWidth: 1,
    borderColor: color_orange,
    borderRadius: 20,
  },
  image: {
    width: widthImage,
    height: widthImage,
  },
});
